Coverage for /Users/davegaeddert/Developer/dropseed/plain/plain-sessions/plain/sessions/migrations/0001_initial.py: 100%

1 import plain.sessions.models

2 from plain import models

3 from plain.models import migrations

4

5

6 class Migration(migrations.Migration):

7 dependencies = []

8

9 operations = [

10 migrations.CreateModel(

11 name="Session",

12 fields=[

13 (

14 "session_key",

15 models.CharField(

16 max_length=40,

17 primary_key=True,

18 ),

19 ),

20 ("session_data", models.TextField()),

21 (

22 "expire_date",

23 models.DateTimeField(db_index=True),

24 ),

25 ],

26 options={

27 "abstract": False,

28 },

29 managers=[

30 ("objects", plain.sessions.models.SessionManager()),

31 ],

32 ),

33 ]